==> aria2-1.7.2.tar.xz: aria2-1.7.2/src/ProtocolDetector.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "ProtocolDetector.h"

#include <cstring>
#include <fstream>
#include <iomanip>

#include "Request.h"
#include "File.h"
#include "util.h"
#ifdef ENABLE_BITTORRENT
# include "bittorrent_helper.h"
#endif // ENABLE_BITTORRENT

namespace aria2 {

ProtocolDetector::ProtocolDetector() {}

ProtocolDetector::~ProtocolDetector() {}

bool ProtocolDetector::isStreamProtocol(const std::string& uri) const
{
  return Request().setUrl(uri);
}

bool ProtocolDetector::guessTorrentFile(const std::string& uri) const
{
  if(!File(uri).isFile()) {
    return false;
  }
  std::ifstream in(uri.c_str(), std::ios::binary);
  if(in) {
    char head;
    in >> head;
    return head == 'd';
  } else {
    return false;
  }
}

bool ProtocolDetector::guessTorrentMagnet(const std::string& uri) const
{
#ifdef ENABLE_BITTORRENT
  try {
    bittorrent::parseMagnet(uri);
    return true;
  } catch(RecoverableException& e) {
    return false;
  }
#else // !ENABLE_BITTORRENT
  return false;
#endif // !ENABLE_BITTORRENT
}

bool ProtocolDetector::guessMetalinkFile(const std::string& uri) const
{
  if(!File(uri).isFile()) {
    return false;
  }
  std::ifstream in(uri.c_str(), std::ios::binary);
  if(in) {
    char head[6];
    in >> std::setw(6) >> head;
    return strcmp(head, "<?xml") == 0;
  } else {
    return false;
  }
}

} // namespace aria2

==> aria2-1.10.0.tar.xz: aria2-1.10.0/src/ProtocolDetector.cc <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#include "ProtocolDetector.h"

#include <cstring>
#include <fstream>
#include <iomanip>

#include "Request.h"
#include "File.h"
#include "util.h"
#include "RecoverableException.h"
#ifdef ENABLE_BITTORRENT
# include "bittorrent_helper.h"
#endif // ENABLE_BITTORRENT

namespace aria2 {

ProtocolDetector::ProtocolDetector() {}

ProtocolDetector::~ProtocolDetector() {}

bool ProtocolDetector::isStreamProtocol(const std::string& uri) const
{
  return Request().setUri(uri);
}

bool ProtocolDetector::guessTorrentFile(const std::string& uri) const
{
  if(!File(uri).isFile()) {
    return false;
  }
  std::ifstream in(uri.c_str(), std::ios::binary);
  if(in) {
    char head;
    in >> head;
    return head == 'd';
  } else {
    return false;
  }
}

bool ProtocolDetector::guessTorrentMagnet(const std::string& uri) const
{
#ifdef ENABLE_BITTORRENT
  try {
    bittorrent::parseMagnet(uri);
    return true;
  } catch(RecoverableException& e) {
    return false;
  }
#else // !ENABLE_BITTORRENT
  return false;
#endif // !ENABLE_BITTORRENT
}

bool ProtocolDetector::guessMetalinkFile(const std::string& uri) const
{
  if(!File(uri).isFile()) {
    return false;
  }
  std::ifstream in(uri.c_str(), std::ios::binary);
  if(in) {
    char head[6];
    in >> std::setw(6) >> head;
    return strcmp(head, "<?xml") == 0;
  } else {
    return false;
  }
}

} // namespace aria2
